<template>
  <section
    v-show="sportsVenue.shop_color && sportsVenue.shop_style"
    :class="{ ['color' + sportsVenue.shop_color]: true, ['layout' + sportsVenue.shop_style]: true }"
    class="sports-venue">
    <div class="shop-html">
      <div class="shop-body">
        <div class="headerwidthcontainer">
          <div id="topnavbar">
            <div
              v-if="sportsVenue.admin"
              id="menu">
              <ul
                id="nav"
                class="tab-buttons">
                <router-link
                  :to="{name: 'sports_venuemain'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'sports_venuemain')}"
                    class="tab">Home
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'sports_venueaccounting'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'sports_venueaccounting')}"
                    class="tab">Accounting</a>
                </router-link>
                <div class="clear"/>
              </ul>
            </div>
          </div>
          <div id="yatlogo">
            <img
              id="yatlogoimg"
              :src="logo"
              width="98"
              height="81">
          </div>
          <div class="banner">
            <div id="shopname">{{ sportsVenue.name }}</div>
            <div
              id="tagline"
              :class="{jumbotron: sportsVenue.shop_style === 2}">
              <p>{{ sportsVenue.description }}</p>
            </div>
          </div>
        </div>
        <div class="clear"/>
        <div class="contentwidthcontainer">
          <div class="thecontent">
            <div id="sidebar">
              <headlines />
              <action-buttons
                v-if="Object.keys(sportsVenue).length"
                :has-swiper="hasSwiper"
                :shop="sportsVenue"/>
            </div>
            <div id="maincontent">
              <router-view
                :shop="sportsVenue"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo" />
            </div>

          </div>
          <div class="clear"/>
        </div>

      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    Headlines,
    ActionButtons,
  },
  extends: ShopBaseView,
  data() {
    return {
      logo: app.network.data.shop_logo,
      sportsVenue: {},
      hasSwiper: app.computerSettings.swiper,
    };
  },
  created: function () {
    this.getData();
  },
  beforeMount: function () {
    this.$router.push({name: "sports_venuemain"});
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/sports_venue/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.sportsVenue = Response;
            app.Message( "Successfully loaded the Sports Venue!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    simpleOne() {
      this.sportsVenue.shop_style = 1;
      this.sportsVenue.shop_color = 1;
    },
    simpleTwo() {
      this.sportsVenue.shop_style = 1;
      this.sportsVenue.shop_color = 2;
    },
    busyOne() {
      this.sportsVenue.shop_style = 2;
      this.sportsVenue.shop_color = 1;
    },
    busyTwo() {
      this.sportsVenue.shop_style = 2;
      this.sportsVenue.shop_color = 2;
    },
  },

};
</script>

<style lang="less">
.sports-venue.layout1.color1 {
  /* Sports Venue common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color1
  @bgcolor: #0a2038;
  @topnavcolor: rgba(0,0,0,0.3);
  @shoptitlecolor: #EB2E2F;
  @logoborder: 0.5rem solid #daa900;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @navbgcolor: #fccb42;
  @tabfontcolor: #EB2E2F;
  @maincontentp:#EB2E2F;
  @maincontenth1:#EB2E2F;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#EB2E2F;
  @buttonborder:#FFF;
  @buttonhoverbg:#0a2038;
  @buttonp: #fff;
  @buttonborderhover:#EB2E2F;
  @factsbg:#fff;
  @factsh2:#FFF;
  @factstitlebg:#EB2E2F;
  @factslistcolor:#FFF;
  @factscolor: black;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @sportsimage: url(/images/shop/sportsvenue/soccer-blue.jpg);

  @import '../../shared.less';
  @import './sportsVenueLayout1.less';
}

</style>

<style lang="less">
.sports-venue.layout1.color2 {
  /* Sports Venue common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color2
  @bgcolor: #153E1E;
  @topnavcolor: rgba(0,0,0,0.3);
  @shoptitlecolor: #348035;
  @logoborder: 0.5rem solid #348035;
  @shopdesccolor:#b33636;
  @homemsgcolor:#7f0000;
  @navbgcolor: #2e55b0;
  @tabfontcolor: #348035;
  @maincontentp:#348035;
  @maincontenth1:#348035;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#348035;
  @buttonborder:#FFF;
  @buttonborderhover:#FFF;
  @buttonhoverbg:#153E1E;
  @buttonp: #fff;
  @factsbg:#fff;
  @factstitlebg:#348035;
  @factsh2:#fff;
  @factslistcolor:#ffff;
  @factscolor:#204045;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @sportsimage: url(/images/shop/sportsvenue/soccer-red.jpg);

  @import '../../shared.less';
  @import './sportsVenueLayout1.less';
  }
  </style>

  <style lang="less">
  .sports-venue.layout2.color1 {
  /* Sports Venue common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color1
  @bgcolor: #163B53;
  @maincontentbg: rgba(163, 212, 245, 1);
  @topnavcolor: rgba(0,0,0,0.3);
  @shoptitlecolor: #833139;
  @logoborder: 0.5rem solid #163B53;
  @shopdesccolor:#224d66;
  @homemsgcolor:#144a68;
  @navbgcolor: #fccb42;
  @tabfontcolor: #833139;
  @maincontentp:#163B53;
  @maincontenth1:#163B53;
  @h1shadow:none;
  @activetabcolor:#FFFF;
  @buttonbackground:#163B53;
  @buttonborder:#fff;
  @buttonhoverbg:#224d66;
  @buttonborderhover:#2e6484;
  @buttonp: #fff;
  @factsbg:#FFF;
  @factsh2:#FFF;
  @factstitlebg:#163B53;
  @factslistcolor:#ffff;
  @factscolor:#163B53;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @sportsimage: url(/images/shop/sportsvenue/hockey.jpg);

  @import '../../shared.less';
  @import './sportsVenueLayout2.less';
}
</style>

<style lang="less">
.sports-venue.layout2.color2 {
  /* Sports Venue common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color2
  @bgcolor: #2878b6;
  @maincontentbg: rgba(249, 222, 174, 1);
  @topnavcolor: rgba(0,0,0,0.2);
  @shoptitlecolor: #2878b6;
  @logoborder: 0.5rem solid #2878b6;
  @shopdesccolor:#fff;
  @homemsgcolor:#7f0000;
  @navbgcolor: #2e55b0;
  @tabfontcolor: #2878b6;
  @maincontentp:#45686e;
  @maincontenth1:#2878b6;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#2878b6;
  @buttonborder:#FFF;
  @buttonborderhover:#FFFF;
  @buttonhoverbg:#1c547f;
  @buttonp: #fff;
  @factsbg:#FFF;
  @factstitlebg:#2878b6;
  @factsh2:#FFF;
  @factslistcolor:#fff;
  @factscolor:black;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @sportsimage: url(/images/shop/sportsvenue/basketball.jpg);

  @import '../../shared.less';
  @import './sportsVenueLayout2.less';
}

</style>
